@@ -4,6 +4,7 @@ use serde::Deserializer;
 use serde::Serialize;
 use serde_repr::Deserialize_repr;
 use serde_repr::Serialize_repr;
+use smartstring::alias::String;
 
 #[derive(Debug, Deserialize, Serialize)]
 /// Represents a single title in IMDB; a "title" can be a show, an episode of a show, a movie, etc.  See [TitleType] for a list.
@@ -36,7 +37,7 @@ impl From<TitleFromImdb> for Title /* {{{ */ {
 	}
 } // }}}
 
-#[derive(Debug, Deserialize_repr, Eq, PartialEq, Serialize_repr, strum::Display)]
+#[derive(Clone, Copy, Debug, Deserialize_repr, Eq, PartialEq, Serialize_repr, strum::IntoStaticStr)]
 #[repr(u8)]
 /// Identifies the type of a [Title].  IMDB has more possible values that, because this crate is opinionated, we collapse down.
 ///
